==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_jv.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_jv extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "Rp" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Dirham Uni Emirat Arab" },
            { "afn", "Afghani Afganistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antilla Walanda" },
            { "aoa", "Kwanza Angola" },
            { "ars", "Peso Argentina" },
            { "aud", "Dolar Australia" },
            { "awg", "Florin Aruban" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Mark Konvertibel Bosnia-Herzegovina" },
            { "bbd", "Dolar Barbadian" },
            { "bdt", "Taka Bangladesh" },
            { "bgn", "Lev Bulgaria" },
            { "bhd", "Bahrain Dinar" },
            { "bif", "Franc Burundi" },
            { "bmd", "Dolar Bermuda" },
            { "bnd", "Dolar Brunai" },
            { "bob", "Boliviano Bolivia" },
            { "brl", "Real Brasil" },
            { "bsd", "Dolar Bahamian" },
            { "btn", "Ngultrum Bhutan" },
            { "bwp", "Pula Botswana" },
            { "byn", "Ruble Belarusia" },
            { "bzd", "Dolar Belise" },
            { "cad", "Dolar Kanada" },
            { "cdf", "Franc Kongo" },
            { "chf", "Franc Swiss" },
            { "clp", "Peso Chili" },
            { "cnh", "Yuan Cina (Jaban Rangkah)" },
            { "cny", "Yuan Cina" },
            { "cop", "Peso Kolumbia" },
            { "crc", "Colon Kosta Rika" },
            { "cuc", "Peso Konvertibel Kuba" },
            { "cup", "Peso Kuba" },
            { "cve", "Escudo Tanjung Verde" },
            { "czk", "Koruna Czech" },
            { "djf", "Franc Djibouti" },
            { "dkk", "Krone Denmark" },
            { "dop", "Peso Dominika" },
            { "dzd", "Dinar Algeria" },
            { "egp", "Pound Mesir" },
            { "ern", "Nakfa Eritrea" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Dolar Fiji" },
            { "fkp", "Pound Kepuloan Falkland" },
            { "gbp", "Pound Inggris" },
            { "gel", "Lari Georgia" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Pound Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Franc Guinea" },
            { "gtq", "Quetzal Guatemala" },
            { "gyd", "Dolar Guyana" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Kroasia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Forint Hungaria" },
            { "idr", "Rupiah Indonesia" },
            { "ils", "Shekel Anyar Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Dinar Irak" },
            { "irr", "Rial Iran" },
            { "isk", "Krona Islandia" },
            { "jmd", "Dolar Jamaika" },
            { "jod", "Dinar Yordania" },
            { "jpy", "Yen Jepang" },
            { "kes", "Shilling Kenya" },
            { "kgs", "Som Kirgistan" },
            { "khr", "Riel Kamboja" },
            { "kmf", "Franc Komoro" },
            { "kpw", "Won Korea Lor" },
            { "krw", "Won Korea Kidul" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Dolar Kepuloan Caiman" },
            { "kzt", "Tenge Kasakhstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Pound Libanon" },
            { "lkr", "Rupee Sri Lanka" },
            { "lrd", "Dolar Liberia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Maroko" },
            { "mdl", "Leu Moldova" },
            { "mga", "Ariary Malagasi" },
            { "mkd", "Denar Masedonia" },
            { "mmk", "Kyat Myanmar" },
            { "mnt", "Tugrik Mongol" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973 - 2017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rupee Mauritius" },
            { "mvr", "Rufiyaa Maladewa" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Meksiko" },
            { "myr", "Ringgit Malaysia" },
            { "mzn", "Metical Mosambik" },
            { "nad", "Dolar Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nio", "Cordoba Nikaragua" },
            { "nok", "Krone Norwegia" },
            { "npr", "Rupee Nepal" },
            { "nzd", "Dolar Selandia Anyar" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pen", "Sol Peru" },
            { "pgk", "Kina Papua Nugini" },
            { "php", "Piso Filipina" },
            { "pkr", "Rupee Pakistan" },
            { "pln", "Zloty Polandia" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "ron", "Leu Rumania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rubel Rusia" },
            { "rwf", "Franc Rwanda" },
            { "sar", "Riyal Saudi" },
            { "sbd", "Dolar Kepuloan Solomon" },
            { "scr", "Rupee Seichelles" },
            { "sdg", "Pound Sudan" },
            { "sek", "Krona Swedia" },
            { "sgd", "Dolar Singapura" },
            { "shp", "Pound Santa Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Shilling Somalia" },
            { "srd", "Dolar Suriname" },
            { "ssp", "Pound Sudan Kidul" },
            { "stn", "Dobra Sao Tome lan Principe" },
            { "syp", "Pound Siria" },
            { "szl", "Lilangeni Swasi" },
            { "thb", "Baht Thai" },
            { "tjs", "Somoni Tajikistan" },
            { "tmt", "Manat Turmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u02bbanga Tonga" },
            { "try", "Lira Turki" },
            { "ttd", "Dolar Trinidad lan Tobago" },
            { "twd", "Dolar Anyar Taiwan" },
            { "tzs", "Shilling Tansania" },
            { "uah", "Hryvnia Ukrania" },
            { "ugx", "Shilling Uganda" },
            { "usd", "Dolar Amerika Serikat" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Usbekistan" },
            { "vef", "Bolivar Venezuela (2008 - 2018)" },
            { "ves", "Bolivar Venezuela" },
            { "vnd", "Dong Vietnam" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "CFA Franc Afrika Tengah" },
            { "xcd", "Dolar Karibia Wetan" },
            { "xof", "CFA Franc Afrika Kulon" },
            { "xpf", "Franc CFP" },
            { "xxx", "Dhuwit Ora Dikenali" },
            { "yer", "Rial Yaman" },
            { "zar", "Rand Afrika Kidul" },
            { "zmw", "Kwacha Sambia" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_jv.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_jv extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "IDR", "Rp" },
            { "MRO", "MRO" },
            { "VEF", "VEF" },
            { "aed", "Dirham Uni Emirat Arab" },
            { "afn", "Afghani Afganistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antilla Walanda" },
            { "aoa", "Kwanza Angola" },
            { "ars", "Peso Argentina" },
            { "aud", "Dolar Australia" },
            { "awg", "Florin Aruban" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Mark Konvertibel Bosnia-Herzegovina" },
            { "bbd", "Dolar Barbadian" },
            { "bdt", "Taka Bangladesh" },
            { "bgn", "Lev Bulgaria" },
            { "bhd", "Bahrain Dinar" },
            { "bif", "Franc Burundi" },
            { "bmd", "Dolar Bermuda" },
            { "bnd", "Dolar Brunai" },
            { "bob", "Boliviano Bolivia" },
            { "brl", "Real Brasil" },
            { "bsd", "Dolar Bahamian" },
            { "btn", "Ngultrum Bhutan" },
            { "bwp", "Pula Botswana" },
            { "byn", "Ruble Belarusia" },
            { "bzd", "Dolar Belise" },
            { "cad", "Dolar Kanada" },
            { "cdf", "Franc Kongo" },
            { "chf", "Franc Swiss" },
            { "clp", "Peso Chili" },
            { "cnh", "Yuan Tyongkok (Jaban Rangkah)" },
            { "cny", "Yuan Tyongkok" },
            { "cop", "Peso Kolumbia" },
            { "crc", "Colon Kosta Rika" },
            { "cuc", "Peso Konvertibel Kuba" },
            { "cup", "Peso Kuba" },
            { "cve", "Escudo Tanjung Verde" },
            { "czk", "Koruna Czech" },
            { "djf", "Franc Djibouti" },
            { "dkk", "Krone Denmark" },
            { "dop", "Peso Dominika" },
            { "dzd", "Dinar Algeria" },
            { "egp", "Pound Mesir" },
            { "ern", "Nakfa Eritrea" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Dolar Fiji" },
            { "fkp", "Pound Kepuloan Falkland" },
            { "gbp", "Pound Inggris" },
            { "gel", "Lari Georgia" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Pound Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Franc Guinea" },
            { "gtq", "Quetzal Guatemala" },
            { "gyd", "Dolar Guyana" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Kroasia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Forint Hungaria" },
            { "idr", "Rupiah Indonesia" },
            { "ils", "Shekel Anyar Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Dinar Irak" },
            { "irr", "Rial Iran" },
            { "isk", "Krona Islandia" },
            { "jmd", "Dolar Jamaika" },
            { "jod", "Dinar Yordania" },
            { "jpy", "Yen Jepang" },
            { "kes", "Shilling Kenya" },
            { "kgs", "Som Kirgistan" },
            { "khr", "Riel Kamboja" },
            { "kmf", "Franc Komoro" },
            { "kpw", "Won Korea Lor" },
            { "krw", "Won Korea Kidul" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Dolar Kepuloan Caiman" },
            { "kzt", "Tenge Kasakhstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Pound Libanon" },
            { "lkr", "Rupee Sri Lanka" },
            { "lrd", "Dolar Liberia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Maroko" },
            { "mdl", "Leu Moldova" },
            { "mga", "Ariary Malagasi" },
            { "mkd", "Denar Masedonia" },
            { "mmk", "Kyat Myanmar" },
            { "mnt", "Tugrik Mongol" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973 - 2017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rupee Mauritius" },
            { "mvr", "Rufiyaa Maladewa" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Meksiko" },
            { "myr", "Ringgit Malaysia" },
            { "mzn", "Metical Mosambik" },
            { "nad", "Dolar Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nio", "Cordoba Nikaragua" },
            { "nok", "Krone Norwegia" },
            { "npr", "Rupee Nepal" },
            { "nzd", "Dolar Selandia Anyar" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pen", "Sol Peru" },
            { "pgk", "Kina Papua Nugini" },
            { "php", "Piso Filipina" },
            { "pkr", "Rupee Pakistan" },
            { "pln", "Zloty Polandia" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "ron", "Leu Rumania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rubel Rusia" },
            { "rwf", "Franc Rwanda" },
            { "sar", "Riyal Saudi" },
            { "sbd", "Dolar Kepuloan Solomon" },
            { "scr", "Rupee Seichelles" },
            { "sdg", "Pound Sudan" },
            { "sek", "Krona Swedia" },
            { "sgd", "Dolar Singapura" },
            { "shp", "Pound Santa Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Shilling Somalia" },
            { "srd", "Dolar Suriname" },
            { "ssp", "Pound Sudan Kidul" },
            { "stn", "Dobra Sao Tome lan Principe" },
            { "syp", "Pound Siria" },
            { "szl", "Lilangeni Swasi" },
            { "thb", "Baht Thai" },
            { "tjs", "Somoni Tajikistan" },
            { "tmt", "Manat Turmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u02bbanga Tonga" },
            { "try", "Lira Turki" },
            { "ttd", "Dolar Trinidad lan Tobago" },
            { "twd", "Dolar Anyar Taiwan" },
            { "tzs", "Shilling Tansania" },
            { "uah", "Hryvnia Ukrania" },
            { "ugx", "Shilling Uganda" },
            { "usd", "Dolar Amerika Serikat" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Usbekistan" },
            { "vef", "Bolivar Venezuela (2008 - 2018)" },
            { "ves", "Bolivar Venezuela" },
            { "vnd", "Dong Vietnam" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "CFA Franc Afrika Tengah" },
            { "xcd", "Dolar Karibia Wetan" },
            { "xof", "CFA Franc Afrika Kulon" },
            { "xpf", "Franc CFP" },
            { "xxx", "Dhuwit Ora Dikenali" },
            { "yer", "Rial Yaman" },
            { "zar", "Rand Afrika Kidul" },
            { "zmw", "Kwacha Sambia" },
        };
        return data;
    }
}
